Module api

Module api 

Framework-neutral API contracts.

Re-exports

pub use body::parse_request_body;
pub use routes::core_auth_async_endpoints;

Modules

additional_fields
body
Request body parsing helpers for framework-neutral auth endpoints.
output
Shared API output helpers for core routes and server-side plugins.
routes
Framework-neutral auth route builders.

Structs

ApiErrorResponse
AsyncAuthEndpoint
AuthEndpoint
AuthEndpointOptions
AuthRouter
BodyField
BodySchema
EndpointInfo
EndpointMiddleware
OpenApiOperation
PathParams
RequestBaseUrl

Enums

ApiErrorCode
EndpointKind
JsonSchemaType

Functions

api_error
append_cookies
async_auth_handler
Wraps an async handler so endpoint authors do not need Box::pin.
async_endpoint_middleware
Wraps async endpoint middleware so authors do not need Box::pin.
build_openapi_schema
core_endpoints
create_auth_endpoint
Defines an async auth endpoint without manual Box::pin.
create_auth_endpoint_raw
empty_openapi_response
fresh_session_middleware
Require the current request’s session to be within SessionOptions::fresh_age.
json_openapi_response
json_response
ok_endpoint
path_param
query_param
redirect_openapi_response
redirect_response
redirect_with_error_response
request_base_url
require_resource_ownership
Require the resource identified by a path param to belong to the current user.
response
serialize_cookie
session_cookies

Type Aliases

ApiRequest
ApiResponse
AsyncEndpointHandler
Body
EndpointFuture
EndpointHandler
EndpointMiddlewareFuture
EndpointMiddlewareHandler