pub fn current_request_path() -> Result<Option<String>, RustAuthError>Expand description
Read the normalized endpoint path for this request, when available.
pub fn current_request_path() -> Result<Option<String>, RustAuthError>Read the normalized endpoint path for this request, when available.