pub fn current_session_user() -> Result<Option<Value>, RustAuthError>Expand description
Read the current session user JSON for this request, when an endpoint resolved one.
pub fn current_session_user() -> Result<Option<Value>, RustAuthError>Read the current session user JSON for this request, when an endpoint resolved one.