pub fn symmetric_encrypt(
key: impl SecretSource,
data: &str,
) -> Result<String, RustAuthError>Expand description
Encrypt a string with either a raw secret or a versioned secret config.
pub fn symmetric_encrypt(
key: impl SecretSource,
data: &str,
) -> Result<String, RustAuthError>Encrypt a string with either a raw secret or a versioned secret config.