pub struct AuthSchema<'a> { /* private fields */ }Expand description
Schema view for validated table and field names.
Implementations
Sourceimpl<'a> AuthSchema<'a>
impl<'a> AuthSchema<'a>
pub fn new(schema: &'a DbSchema) -> Self
Sourcepub fn table(
&self,
logical_name: &str,
) -> Result<SchemaTable<'a>, RustAuthError>
pub fn table( &self, logical_name: &str, ) -> Result<SchemaTable<'a>, RustAuthError>
Resolve a logical table name and return a handle for validation/mapping.
Sourcepub fn try_table(&self, logical_name: &str) -> Option<SchemaTable<'a>>
pub fn try_table(&self, logical_name: &str) -> Option<SchemaTable<'a>>
Resolve a logical table when it exists in the merged schema.