pub struct TableOptions {
pub name: Option<String>,
pub field_names: IndexMap<String, String>,
pub additional_fields: IndexMap<String, DbField>,
}Expand description
Per-table schema overrides.
Fields
name: Option<String>field_names: IndexMap<String, String>additional_fields: IndexMap<String, DbField>Implementations
Sourceimpl TableOptions
impl TableOptions
Sourcepub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
Return a copy of these options with a custom database table name.
Sourcepub fn with_field_name(
self,
logical_name: impl Into<String>,
db_name: impl Into<String>,
) -> Self
pub fn with_field_name( self, logical_name: impl Into<String>, db_name: impl Into<String>, ) -> Self
Return a copy of these options with a custom database column name.
Sourcepub fn with_field(self, logical_name: impl Into<String>, field: DbField) -> Self
pub fn with_field(self, logical_name: impl Into<String>, field: DbField) -> Self
Return a copy of these options with an additional logical field.