pub struct RateLimitDecision {
pub permitted: bool,
pub retry_after: u64,
pub limit: u64,
pub remaining: u64,
pub reset_after: u64,
}Fields
permitted: boolretry_after: u64Seconds until the client may retry when permitted is false.
limit: u64remaining: u64reset_after: u64Trait Implementations
Sourceimpl Clone for RateLimitDecision
impl Clone for RateLimitDecision
Sourcefn clone(&self) -> RateLimitDecision
fn clone(&self) -> RateLimitDecision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateLimitDecision
impl Debug for RateLimitDecision
impl Eq for RateLimitDecision
Sourceimpl PartialEq for RateLimitDecision
impl PartialEq for RateLimitDecision
Sourcefn eq(&self, other: &RateLimitDecision) -> bool
fn eq(&self, other: &RateLimitDecision) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RateLimitDecision