pub fn dispatch_outbound(context: &AuthContext, send: OutboundSendFuture)Expand description
Dispatches outbound delivery on a background task without blocking the caller.
pub fn dispatch_outbound(context: &AuthContext, send: OutboundSendFuture)Dispatches outbound delivery on a background task without blocking the caller.