pub struct SecretString(/* private fields */);Expand description
Secret string wrapper that redacts its value in Debug output.
Implementations
Sourceimpl SecretString
impl SecretString
Sourcepub fn expose_secret(&self) -> &str
pub fn expose_secret(&self) -> &str
Borrow the raw secret value.
Prefer passing the secret directly to crypto or HTTP client code and avoid logging this value.
Sourcepub fn into_inner(self) -> String
pub fn into_inner(self) -> String
Consume the wrapper and return the raw secret value.