Module verification

Module verification 

Database-backed verification token/value helpers.

Structs

CreateVerificationInput
DbVerificationStore
UpdateVerificationInput
VerificationStore
Verification store that uses configured secondary storage when present.

Functions

process_verification_identifier
Transform a verification identifier according to configured storage options.